.. image:: graphics/logo.png
    :width: 350px
    :align: center
    :height: 80px
    :alt: openclean-logo


Welcome to openclean's Notebook UI Documentation!
=================================================

This package provides a graphical user interface for **openclean** that can be used to visualize and manipulate datasets in notebook environments like Jupyter Notebooks.


..  toctree::
    :maxdepth: 2
    :caption: Contents:

    source/installation
    source/usage

.. _api-ref:

..  toctree::
    :maxdepth: 1
    :caption: API Reference:

    source/api/modules
